==> gcomp_2.0.4.beta.zip: TaskDecompile.cpp <==
// TaskDecompile.cpp: implementation of the CTaskDecompile class.
//////////////////////////////////////////////////////////////////////

#include <io.h>
#include "Task.h"
#include "CommonFunctions.h"
#include "Storage.h"
#include "NameTable.h"

#ifdef _DEBUG
#undef THIS_FILE
static char THIS_FILE[]=__FILE__;
#define new DEBUG_NEW
#endif

extern CTaskParameters TaskParameters;
extern CNameTable NameTable;

void CTaskDecompile::FindDeletedStreams(CString& Path)
{
	struct _finddata_t find_data;
	long hFind;
	CString Pattern(Path);
	CString FileName;

	Pattern += "\\*.*";
	
	hFind = _findfirst(Pattern, &find_data);
	if( hFind != -1 )
	{
		do
		{
			if (0 == strcmp(find_data.name, ".")) continue;
			if (0 == strcmp(find_data.name, "..")) continue;
			if (0 == stricmp(find_data.name, "CVS")) continue;

			FileName.Format("%s\\%s", Path, find_data.name);

			if( (find_data.attrib & _A_SUBDIR) != 0 )
			{
				FindDeletedStreams(FileName);
			}
			else
			{
				CheckPrune(FileName);
			}
		} while( _findnext(hFind, &find_data) == 0 );
		_findclose(hFind);
	}
}


void CTaskDecompile::Action()
{
	CTime Time = CTime::GetCurrentTime();

	CStorage Storage;
	Storage.Open(TaskParameters.CompoundFileName);

	CreateDirectory(TaskParameters.DirectoryName);

	CoInitialize(NULL);
	
	CNameTableRecord* nt_rec = NameTable.Find(NT_MainMetadataStream);
	if( TaskParameters.CompoundType == CTaskParameters::external_report )
	{
		MMS = (CMMS*)Storage.ParseStream(nt_rec->StorageName);
	}
	else
	{
		Storage.Open(CString("Metadata"));
		MMS = (CMMS*)Storage.ParseStream(nt_rec->StorageName);
		Storage.Close();
	}

	if( MMS != NULL )
	{
		MMS->Decompile(TaskParameters.DirectoryName, Storage);
		delete MMS;
		FindDeletedStreams(TaskParameters.DirectoryName);
	}

	CoUninitialize();

	CTimeSpan ExtractionTime = CTime::GetCurrentTime() - Time;
	Msg(0, "'%s' extracted into '%s' in %s\n", 
		TaskParameters.CompoundFileName, TaskParameters.DirectoryName, 
		ExtractionTime.Format("%H:%M:%S"));
}

==> gcomp_2.0.5.beta.zip: TaskDecompile.cpp <==
//////////////////////////////////////////////////////////////////////
// TaskDecompile.cpp: implementation of the CTaskDecompile class.
//////////////////////////////////////////////////////////////////////

#include "Declarations.h"
#include "Task.h"
#include "CommonFunctions.h"
#include "MMS.h"
#include "Storage.h"
#include "NameTable.h"

#ifdef _DEBUG
#undef THIS_FILE
static char THIS_FILE[]=__FILE__;
#define new DEBUG_NEW
#endif


void CTaskDecompile::FindDeletedStreams(CString& Path)
{
	struct _finddata_t find_data;
	long hFind;
	CString Pattern(Path);
	CString FileName;

	Pattern += "\\*.*";
	
	hFind = _findfirst(Pattern, &find_data);
	if( hFind != -1 )
	{
		do
		{
			if (0 == strcmp(find_data.name, ".")) continue;
			if (0 == strcmp(find_data.name, "..")) continue;
			if (0 == stricmp(find_data.name, "CVS")) continue;
			if (0 == stricmp(find_data.name, ".svn")) continue;

			FileName.Format("%s\\%s", Path, find_data.name);

			if( (find_data.attrib & _A_SUBDIR) != 0 )
			{
				FindDeletedStreams(FileName);
			}
			else
			{
				CheckPrune(FileName);
			}
		} while( _findnext(hFind, &find_data) == 0 );
		_findclose(hFind);
	}
}


void CTaskDecompile::Action()
{
	CTime Time = CTime::GetCurrentTime();
	if( TaskParameters.Verbose > 1) Msg(0, "\nExtraction started: %s\n", Time.Format("%Y.%m.%d %H:%M:%S"));

	CMMS* MMS = NULL;
	CStorage Storage;
	Storage.Open(TaskParameters.CompoundFileName);

	CreateDirectory(TaskParameters.DirectoryName);

	CoInitialize(NULL);
	
	CNameTableRecord* nt_rec = NameTable.Find(NT_MainMetadataStream);
	if( TaskParameters.CompoundType == CTaskParameters::external_report )
	{
		MMS = (CMMS*)Storage.ParseStream(nt_rec->StorageName);
	}
	else
	{
		Storage.Open(CString("Metadata"));
		MMS = (CMMS*)Storage.ParseStream(nt_rec->StorageName);
		Storage.Close();
	}

	if( MMS != NULL )
	{
		MMS->Decompile(TaskParameters.DirectoryName, Storage);
		delete MMS;
		FindDeletedStreams(TaskParameters.DirectoryName);
	}

	CoUninitialize();

	if( TaskParameters.CompoundType != CTaskParameters::external_report || TaskParameters.Verbose > 1)
	{
		CTimeSpan ExtractionTime = CTime::GetCurrentTime() - Time;
		Msg(0, "'%s' extracted into '%s' in %s\n", 
			TaskParameters.CompoundFileName, TaskParameters.DirectoryName, 
			ExtractionTime.Format("%H:%M:%S"));
	}
}
